@@ -5,6 +5,7 @@ This module provides many utilities based on the csound binary
 from __future__ import annotations
 import math as _math
 import os as _os
+import sys
 import sys as _sys
 import subprocess as _subprocess
 import re as _re
@@ -249,12 +250,51 @@ class _PortaudioBackend(AudioBackend):
         indevs, outdevs = getAudioDevices(self.name)
         indev = next((d for d in indevs if _re.search(r"\bdefault\b", d.name)), None)
         outdev = next((d for d in outdevs if _re.search(r"\bdefault\b", d.name)), None)
-        if indev is None and indevs:
-            indev = indevs[0]
-        if outdev is None and outdevs:
-            outdev = outdevs[0]
+        if indev is None:
+            if not indevs:
+                logger.warning(f"No input devices for backend {self.name}")
+            else:
+                indev = indevs[0]
+        if outdev is None:
+            if not outdevs:
+                logger.warning(f"No output devices for backend {self.name}")
+            else:
+                outdev = outdevs[0]
         return indev, outdev
 
+    def audioDevices(self) -> Tuple[List[AudioDevice], List[AudioDevice]]:
+        indevices, outdevices = [], []
+        proc = csoundSubproc(['-+rtaudio=pa_cb', '-odac', '--devices'], wait=True)
+        if sys.platform == 'win32':
+            lines = proc.stdout.readlines()
+        else:
+            lines = proc.stderr.readlines()
+        for line in lines:
+            line = line.decode("utf-8")
+            if match := _re.search(self.audioDeviceRegex, line):
+                groups = match.groups()
+                if len(groups) == 3:
+                    idxstr, devid, devname = groups
+                    numchannels = None
+                else:
+                    idxstr, devid, devname, numchannels = groups
+                    numchannels = int(numchannels) if numchannels is not None else 2
+                kind = 'input' if devid.startswith("adc") else 'output'
+                dev = AudioDevice(index=int(idxstr), id=devid, name=devname, kind=kind,
+                                  numchannels=numchannels)
+                (indevices if kind == 'input' else outdevices).append(dev)
+            elif match := _re.search(r"(\d+):\s*(dac\d+)\s\((.+)", line):
+                idxstr = match.group(1)
+                devid = match.group(2)
+                devname = match.group(3)
+                kind = 'input' if devid.startswith("adc") else 'output'
+                dev = AudioDevice(index=int(idxstr), id=devid, name=devname, kind=kind,
+                                  numchannels=None)
+                (indevices if kind == 'input' else outdevices).append(dev)
+        return indevices, outdevices
+
+
+
 
 class _AlsaBackend(AudioBackend):
     def __init__(self):
@@ -971,7 +1011,7 @@ class AudioDevice:
     name: str
     kind: str
     index: int = -1
-    numchannels: int = 0
+    numchannels: Optional[int] = 0
 
     def info(self) -> str:
         """
